package com.example.schedulerapp;

import java.io.*;
import java.net.*;
import java.util.*;

public class ScheduleServer {
    private Model model;
    private int port;
    private Set<UserThread> userThreads = new HashSet<>(); // notify when there are changes

    public ScheduleServer(int port) {
        this.port = port;
        this.model = new Model();
    }

    public void execute() {
        try (ServerSocket serverSocket = new ServerSocket(port)) {
            System.out.println("Server is listening on port " + port);

            while (true) {
                Socket socket = serverSocket.accept();

                UserThread newUser = new UserThread(socket, this, this.model);
                userThreads.add(newUser);
                newUser.start();
            }
        } catch (IOException error) {
            System.out.println("Error in the server :" + error.getMessage());
            error.printStackTrace();
        }
    }

    void broadcast(String message) {
        for (UserThread aUser : userThreads) {
            aUser.sendMessage(message);
        }
    }

    void removeUser(UserThread aUser) {
        userThreads.remove(aUser);
    }

    public static void main(String[] args) {
        ScheduleServer server = new ScheduleServer(8989);
        server.execute();
    }
}
